<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>排他ロックを取得できません</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>別のパッケージ管理アプリケーション (Synaptic や apt-get) がすでに実行されています。まずそのアプリケーションを閉じてください</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>このプログラムは root で実行する必要があります。</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX コーデックインストーラ</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;このアプリケーションによって、先進された映像・音楽機能を実現する制限されたコーデックをインストールすることができます。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;ユーザーが条件を満たさなければならないように、若干配布制限が生じるかもしれません。&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;法令を引き受け、これらのコーデックをダウンロードしますか？&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>コーデックファイルのダウンロード中</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>変更をキャンセルして終了</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="270"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>変更を適用して終了</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>About...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>ヘルプを表示</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="103"/>
        <location filename="../mxcodecs.cpp" line="110"/>
        <location filename="../mxcodecs.cpp" line="118"/>
        <location filename="../mxcodecs.cpp" line="126"/>
        <location filename="../mxcodecs.cpp" line="135"/>
        <location filename="../mxcodecs.cpp" line="142"/>
        <location filename="../mxcodecs.cpp" line="151"/>
        <location filename="../mxcodecs.cpp" line="159"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;実行コマンド...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="106"/>
        <location filename="../mxcodecs.cpp" line="122"/>
        <location filename="../mxcodecs.cpp" line="129"/>
        <location filename="../mxcodecs.cpp" line="138"/>
        <location filename="../mxcodecs.cpp" line="144"/>
        <location filename="../mxcodecs.cpp" line="155"/>
        <location filename="../mxcodecs.cpp" line="162"/>
        <location filename="../mxcodecs.cpp" line="194"/>
        <location filename="../mxcodecs.cpp" line="247"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <source>Cannot connect to the download site</source>
        <translation>ダウンロードサイトに接続できません</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="113"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <source>Error downloading %1</source>
        <translation>ダウンロードエラー %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="168"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;ダウンロード完了&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="190"/>
        <source>Installing downloaded files</source>
        <translation>ダウンロードファイルをインストール中</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="195"/>
        <source>No downloaded *.debs files found.</source>
        <translation>ダウンロードした *.deb ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="208"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;インストール中...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="222"/>
        <source>Error installing %1</source>
        <translation>インストールエラー %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="226"/>
        <source>Fix missing dependencies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="228"/>
        <source>Error running &apos;apt-get -fm install&apos; command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="240"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;インストール作業が完了しました&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="243"/>
        <source>Finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="244"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>コーデックファイルのダウンロード・インストールが完了しました。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="248"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>処理が完了しました。インストールでエラーが発生しています。</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>About MX Codecs</source>
        <translation>MX Codes について </translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>MX Codecs</source>
        <translation>MX Codecs</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>MX Linux のシンプルなコーデックダウンローダー</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="268"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="269"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
</TS>
